@@ -121,6 +121,7 @@ __all__ = (
     "StorageInfoTypeDef",
     "TagResourceRequestRequestTypeDef",
     "TlsTypeDef",
+    "UnauthenticatedTypeDef",
     "UnprocessedScramSecretTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateBrokerCountRequestRequestTypeDef",
@@ -137,6 +138,8 @@ __all__ = (
     "UpdateConfigurationResponseTypeDef",
     "UpdateMonitoringRequestRequestTypeDef",
     "UpdateMonitoringResponseTypeDef",
+    "UpdateSecurityRequestRequestTypeDef",
+    "UpdateSecurityResponseTypeDef",
     "ZookeeperNodeInfoTypeDef",
 )
 
@@ -244,6 +247,7 @@ ClientAuthenticationTypeDef = TypedDict(
     {
         "Sasl": "SaslTypeDef",
         "Tls": "TlsTypeDef",
+        "Unauthenticated": "UnauthenticatedTypeDef",
     },
     total=False,
 )
@@ -912,6 +916,8 @@ MutableClusterInfoTypeDef = TypedDict(
         "KafkaVersion": str,
         "LoggingInfo": "LoggingInfoTypeDef",
         "InstanceType": str,
+        "ClientAuthentication": "ClientAuthenticationTypeDef",
+        "EncryptionInfo": "EncryptionInfoTypeDef",
     },
     total=False,
 )
@@ -1079,6 +1085,15 @@ TlsTypeDef = TypedDict(
     "TlsTypeDef",
     {
         "CertificateAuthorityArnList": List[str],
+        "Enabled": bool,
+    },
+    total=False,
+)
+
+UnauthenticatedTypeDef = TypedDict(
+    "UnauthenticatedTypeDef",
+    {
+        "Enabled": bool,
     },
     total=False,
 )
@@ -1271,6 +1286,38 @@ UpdateMonitoringResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateSecurityRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateSecurityRequestRequestTypeDef",
+    {
+        "ClusterArn": str,
+        "CurrentVersion": str,
+    },
+)
+_OptionalUpdateSecurityRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateSecurityRequestRequestTypeDef",
+    {
+        "ClientAuthentication": "ClientAuthenticationTypeDef",
+        "EncryptionInfo": "EncryptionInfoTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateSecurityRequestRequestTypeDef(
+    _RequiredUpdateSecurityRequestRequestTypeDef, _OptionalUpdateSecurityRequestRequestTypeDef
+):
+    pass
+
+
+UpdateSecurityResponseTypeDef = TypedDict(
+    "UpdateSecurityResponseTypeDef",
+    {
+        "ClusterArn": str,
+        "ClusterOperationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ZookeeperNodeInfoTypeDef = TypedDict(
     "ZookeeperNodeInfoTypeDef",
     {
